@@ -29,8 +29,6 @@ import Text.TeXMath.Unicode.ToUnicode
 import Data.Generics (everywhere, mkT)
 import Text.TeXMath.Shared (getMMLType, handleDownup)
 import Text.TeXMath.Readers.MathML.MMLDict (getMathMLOperator)
-import Control.Applicative ((<$>))
-import Data.Semigroup ((<>))
 import qualified Data.Text as T
 import Text.Printf
 
